==> everycomp-1.20-2.8.7-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/fabric/mrcrayfish/MightyMailModule.java <==
package net.mehvahdjukaar.every_compat.modules.fabric.mrcrayfish;

import com.mrcrayfish.mightymail.block.MailboxBlock;
import com.mrcrayfish.mightymail.core.ModBlockEntities;
import com.mrcrayfish.mightymail.core.ModCreativeTabs;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.api.RenderLayer;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_2248;
import net.minecraft.class_2498;
import net.minecraft.class_3481;
import net.minecraft.class_7924;

//SUPPORT: v1.0.14+
public class MightyMailModule extends SimpleModule {

    public final SimpleEntrySet<WoodType, class_2248> mailboxes;

    public MightyMailModule(String modId) {
        super(modId, "mm");

        mailboxes = SimpleEntrySet.builder(WoodType.class, "mail_box",
                        getModBlock("oak_mail_box"), () -> WoodTypeRegistry.OAK_TYPE,
                        w -> new MailboxBlock(Utils.copyPropertySafe(w.planks)
                                .method_9632(3.5F).method_9626(class_2498.field_11547).method_50013()))
                .setTab(ModCreativeTabs.MAIN::get)
                .addTile(ModBlockEntities.MAIL_BOX::get)
                .addTextureM(modRes("block/oak_mail_box"),
                        EveryCompat.res("block/mm/oak_mail_box_m"))
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .setRenderType(RenderLayer.CUTOUT)
                .defaultRecipe()
                .build();
        this.addEntry(mailboxes);
    }
}

==> everycomp-1.20-2.9.9-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/fabric/mrcrayfish/MightyMailModule.java <==
package net.mehvahdjukaar.every_compat.modules.fabric.mrcrayfish;

import com.mrcrayfish.mightymail.block.MailboxBlock;
import com.mrcrayfish.mightymail.core.ModBlockEntities;
import com.mrcrayfish.mightymail.core.ModCreativeTabs;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.api.RenderLayer;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.moonlight.api.set.wood.VanillaWoodTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_2248;
import net.minecraft.class_2498;
import net.minecraft.class_3481;
import net.minecraft.class_7924;

//SUPPORT: v1.0.14+
public class MightyMailModule extends SimpleModule {

    public final SimpleEntrySet<WoodType, class_2248> mailboxes;

    public MightyMailModule(String modId) {
        super(modId, "mm");

        mailboxes = SimpleEntrySet.builder(WoodType.class, "mail_box",
                        getModBlock("oak_mail_box"), () -> VanillaWoodTypes.OAK,
                        w -> new MailboxBlock(Utils.copyPropertySafe(w.planks)
                                .method_9632(3.5F).method_9626(class_2498.field_11547).method_50013()))
                .setTab(ModCreativeTabs.MAIN::get)
                .addTile(ModBlockEntities.MAIL_BOX::get)
                .addTextureM(modRes("block/oak_mail_box"),
                        EveryCompat.res("block/mm/oak_mail_box_m"))
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .setRenderType(RenderLayer.CUTOUT)
                .defaultRecipe()
                .build();
        this.addEntry(mailboxes);
    }
}
